@@ -111,11 +111,11 @@ def exportExperiment(experiment, root_path):
     html = htmlExportService.getHTML(experiment, withImages=True)
     html_with_paths = htmlExportService.insertFilepaths(expDir, html)
 
-    with open(expDir.joinpath('entity.html'), 'w', encoding="utf-8") as out:
+    with open(expDir.joinpath(f'{expDir.name}.html'), 'w', encoding="utf-8") as out:
         out.write(html_with_paths)
 
     # get pdf
     if includePDF:
         pdf = htmlToPDF(experiment.__user__, html)
-        with open(expDir.joinpath('entity.pdf'), 'wb') as out:
+        with open(expDir.joinpath(f'{expDir.name}.pdf'), 'wb') as out:
             out.write(pdf)
