@@ -8,8 +8,8 @@ from labstep.entities.protocolStep.model import ProtocolStep
 from labstep.entities.protocolTable.model import ProtocolTable
 from labstep.entities.protocolTimer.model import ProtocolTimer
 from labstep.entities.protocolVersion.model import ProtocolVersion
-from labstep.entities.protocolMaterial.model import ProtocolMaterial
-import labstep.entities.protocolMaterial.repository as protocolMaterialRepository
+from labstep.entities.protocolInventoryField.model import ProtocolInventoryField
+import labstep.entities.protocolInventoryField.repository as protocolInventoryFieldRepository
 from labstep.generic.entityList.model import EntityList
 from labstep.entities.file.model import File
 import labstep.entities.file.repository as fileRepository
@@ -262,16 +262,16 @@ class Protocol(EntityPrimary):
             extraParams=extraParams,
         )
 
-    def addMaterial(
+    def addInventoryField(
         self, name=UNSPECIFIED, amount=UNSPECIFIED, units=UNSPECIFIED, resource_id=UNSPECIFIED, extraParams={}
     ):
         """
-        Add a new material to the Protocol.
+        Add a new inventory field to the Protocol.
 
         Parameters
         ----------
         name (str)
-            The name of the material to add.
+            The name of the inventory field to add.
         amount (str)
             The amount required by the protocol.
         units (str)
@@ -282,8 +282,8 @@ class Protocol(EntityPrimary):
 
         Returns
         -------
-        :class:`~labstep.entities.protocolMaterial.model.ProtocolMaterial`
-            The newly added material entity.
+        :class:`~labstep.entities.protocolInventoryField.model.ProtocolInventoryField`
+            The newly added inventory field entity.
 
         Example
         -------
@@ -291,38 +291,38 @@ class Protocol(EntityPrimary):
 
             protocol = user.getProtocol(17000)
             resource = user.getResources(search_query='Sample A')[0]
-            protocol.addMaterial(name='Sample A', amount='2', units='ml',
+            protocol.addInventoryField(name='Sample A', amount='2', units='ml',
                                  resource_id=resource.id)
         """
-        return protocolMaterialRepository.newProtocolMaterial(self.__user__,
-                                                              protocol_id=self.last_version["id"],
-                                                              resource_id=resource_id, name=name,
-                                                              amount=amount,
-                                                              units=units,
-                                                              extraParams=extraParams)
+        return protocolInventoryFieldRepository.newProtocolInventoryField(self.__user__,
+                                                                          protocol_id=self.last_version["id"],
+                                                                          resource_id=resource_id, name=name,
+                                                                          amount=amount,
+                                                                          units=units,
+                                                                          extraParams=extraParams)
 
-    def getMaterials(self, count=100, extraParams={}):
+    def getInventoryFields(self, count=100, extraParams={}):
         """
-        Returns a list of the materials in a Protocol.
+        Returns a list of the inventory fields in a Protocol.
 
         Returns
         -------
-        List[:class:`~labstep.entities.protocolMaterial.model.ProtocolMaterial`]
-            List of the materials in a Protocol.
+        List[:class:`~labstep.entities.protocolInventoryField.model.ProtocolInventoryField`]
+            List of the inventory fields in a Protocol.
 
         Example
         -------
         ::
 
             protocol = user.getProtocol(17000)
-            protocol_materials = protocol.getMaterials()
-            protocol_materials[0].attributes()
+            protocol_inventoryFields = protocol.getInventoryFields()
+            protocol_inventory_fields[0]
         """
         self.update()
         if "protocol_values" not in self.last_version:
             return []
-        materials = self.last_version["protocol_values"]
-        return EntityList(materials, ProtocolMaterial, self.__user__)
+        inventoryFields = self.last_version["protocol_values"]
+        return EntityList(inventoryFields, ProtocolInventoryField, self.__user__)
 
     def addTimer(self, name=UNSPECIFIED, hours=UNSPECIFIED, minutes=UNSPECIFIED, seconds=UNSPECIFIED):
         """
@@ -566,10 +566,18 @@ class Protocol(EntityPrimary):
 
         return protocolRepository.exportProtocol(self, path)
 
-    @ deprecated(version='3.3.2', reason="You should use experiment.addDataField instead")
+    @deprecated(version='3.3.2', reason="You should use experiment.addDataField instead")
     def addDataElement(self, *args, **kwargs):
         return self.addDataField(*args, **kwargs)
 
-    @ deprecated(version='3.3.2', reason="You should use experiment.getDataFields instead")
+    @deprecated(version='3.3.2', reason="You should use experiment.getDataFields instead")
     def getDataElements(self):
         return self.getDataFields()
+
+    @deprecated(version='3.12.0', reason="You should use getInventoryFields instead")
+    def getMaterials(self, *args, **kwargs):
+        return self.getInventoryFields(*args, **kwargs)
+
+    @deprecated(version='3.12.0', reason="You should use addInventoryField instead")
+    def addMaterial(self, *args, **kwargs):
+        return self.addInventoryField(*args, **kwargs)
