@@ -142,7 +142,7 @@ def exportEntity(entity, rootPath, folderName=UNSPECIFIED):
 
     if folderName is UNSPECIFIED:
         if entityNameInFolderName and hasattr(
-                entity, 'name'):
+                entity, 'name') and entity.name is not None:
             santitisedName = entity.name.replace('/', ' ').replace('\\', ' ')
             folderName = f"{entity.id} - {santitisedName}"
         else:
@@ -150,7 +150,7 @@ def exportEntity(entity, rootPath, folderName=UNSPECIFIED):
 
     entityDir = Path(rootPath).joinpath(sanitize_filepath(folderName))
     entityDir.mkdir(parents=True, exist_ok=True)
-    infoFile = entityDir.joinpath('entity.json')
+    infoFile = entityDir.joinpath(f'{folderName}.json')
 
     with open(infoFile, 'w') as out:
         json.dump(entity.__data__, out, indent=2)
